@@ -19,6 +19,8 @@ settings.configure(
         'recommends',
         'recommends.storages.djangoorm',
         'recommends.tests',
+        'celery',
+        'djcelery',
     ],
     ROOT_URLCONF='recommends.tests.urls',
     TEMPLATE_DIRS=(
@@ -32,6 +34,7 @@ settings.configure(
     RECOMMENDS_TEST_MONGO=True,
     RECOMMENDS_TEST_RECSYS=True,
     RECOMMENDS_STORAGE_MONGODB_FSYNC=True,
+    RECOMMENDS_TASK_RUN=True,
 )
 
 
